searchData={"items":[{"type":"module","title":"SimpleXml","doc":"This is a thin wrapper around the saxy library.  It leverages the DOM generated by saxy's\nSimpleForm parser and defines some basic operations on the DOM via the `XmlNode` module.\n\nThe main benefit of using saxy's SimpleForm parsing is that it gives us a string presentation of\nthe XML DOM, without exposing the users of this library with the\n[atom exhaustion vulernability](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/xmerl.html)\nof the xmerl library and any parsers based on it.","ref":"SimpleXml.html"},{"type":"function","title":"SimpleXml.parse/1","doc":"Parses an XML string to return a tuple representing the XML node.","ref":"SimpleXml.html#parse/1"},{"type":"function","title":"Examples - SimpleXml.parse/1","doc":"#","ref":"SimpleXml.html#parse/1-examples"},{"type":"function","title":"Well-formed XMLs are successfully parsed - SimpleXml.parse/1","doc":"iex> SimpleXml.parse(~S{ body })\n    {:ok, {\"foo\", [{\"attr1\", \"value1\"}, {\"attr2\", \"value2\"}], [\"body\"]}}\n\n    #","ref":"SimpleXml.html#parse/1-well-formed-xmls-are-successfully-parsed"},{"type":"function","title":"Malformed XMLs result in an error - SimpleXml.parse/1","doc":"iex> SimpleXml.parse(\"<foo\")\n    {:error, %Saxy.ParseError{reason: {:token, :name_start_char}, binary: \"<foo\", position: 4}}","ref":"SimpleXml.html#parse/1-malformed-xmls-result-in-an-error"},{"type":"type","title":"SimpleXml.xml_attribute/0","doc":"","ref":"SimpleXml.html#t:xml_attribute/0"},{"type":"type","title":"SimpleXml.xml_node/0","doc":"","ref":"SimpleXml.html#t:xml_node/0"},{"type":"module","title":"SimpleXml.XmlNode","doc":"A simplistic XML node representation that uses the saxy lib, in order to avoid xmerl based\nlibraries, which have the vulnerability that they create new atoms for each tag within the XML\ndocument.\n\nFor simplicity, this module ignores namespaces within the document.","ref":"SimpleXml.XmlNode.html"},{"type":"function","title":"SimpleXml.XmlNode.attribute/2","doc":"Obtains value for the given attribute.","ref":"SimpleXml.XmlNode.html#attribute/2"},{"type":"function","title":"Examples - SimpleXml.XmlNode.attribute/2","doc":"#","ref":"SimpleXml.XmlNode.html#attribute/2-examples"},{"type":"function","title":"Obtains the value for an attribute - SimpleXml.XmlNode.attribute/2","doc":"Assume that the following XML has been parsed.\n    ```\n        \n    ```\n\n    iex> SimpleXml.XmlNode.attribute({\"foo\", [{\"a\", 1}, \"b\", 2], []}, \"a\")\n    {:ok, 1}\n\n    #","ref":"SimpleXml.XmlNode.html#attribute/2-obtains-the-value-for-an-attribute"},{"type":"function","title":"Returns the first matching attribute it finds - SimpleXml.XmlNode.attribute/2","doc":"Assume that the following XML has been parsed.\n    ```\n        \n    ```\n\n    iex> SimpleXml.XmlNode.attribute({\"foo\", [{\"a\", 1}, \"a\", 2], []}, \"a\")\n    {:ok, 1}\n\n    #","ref":"SimpleXml.XmlNode.html#attribute/2-returns-the-first-matching-attribute-it-finds"},{"type":"function","title":"Generates an error when the attribute is missing - SimpleXml.XmlNode.attribute/2","doc":"Assume that the following XML has been parsed.\n    ```\n        \n    ```\n    iex> SimpleXml.XmlNode.attribute({\"foo\", [{\"a\", 1}, \"b\", 2], []}, \"c\")\n    {:error, {:attribute_not_found, \"c\"}}","ref":"SimpleXml.XmlNode.html#attribute/2-generates-an-error-when-the-attribute-is-missing"},{"type":"function","title":"SimpleXml.XmlNode.first_child/2","doc":"Obtains the first child of the given node with the given string tag name via case-insensitive\nmatch.\n\nUse a \"*:\" prefix for the tag name to ignore namespace associated with the tag name.\n\nAlternatively, you can supply a regex to pattern match the child name.  When Regex is supplied the\nRegex's case sensitivity is respected.","ref":"SimpleXml.XmlNode.html#first_child/2"},{"type":"function","title":"Examples - SimpleXml.XmlNode.first_child/2","doc":"#","ref":"SimpleXml.XmlNode.html#first_child/2-examples"},{"type":"function","title":"Obtains the first child by the given name. - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  2  \n    ```\n\n    iex> SimpleXml.XmlNode.first_child({\"foo\", [], [{\"bar\", [], [\"1\"]}, {\"baz\", [], [\"2\"]}]}, \"bar\")\n    {:ok, {\"bar\", [], [\"1\"]}}\n\n    #","ref":"SimpleXml.XmlNode.html#first_child/2-obtains-the-first-child-by-the-given-name"},{"type":"function","title":"Returns the first matching node it finds - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  2  \n    ```\n\n    iex> SimpleXml.XmlNode.first_child({\"foo\", [], [{\"bar\", [], [\"1\"]}, {\"bar\", [], [\"2\"]}]}, \"bar\")\n    {:ok, {\"bar\", [], [\"1\"]}}\n\n    #","ref":"SimpleXml.XmlNode.html#first_child/2-returns-the-first-matching-node-it-finds"},{"type":"function","title":"Ignores case when matching tag name - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  2  \n    ```\n\n    iex> SimpleXml.XmlNode.first_child({\"foo\", [], [{\"bar\", [], [\"1\"]}, {\"bar\", [], [\"2\"]}]}, \"BAR\")\n    {:ok, {\"bar\", [], [\"1\"]}}\n\n    #","ref":"SimpleXml.XmlNode.html#first_child/2-ignores-case-when-matching-tag-name"},{"type":"function","title":"Wildcard ignores tag namespace - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  2  \n    ```\n\n    iex> SimpleXml.XmlNode.first_child({\"ns:foo\", [], [{\"xs:bar\", [], [\"1\"]}, {\"xs:bar\", [], [\"2\"]}]}, \"*:bar\")\n    {:ok, {\"xs:bar\", [], [\"1\"]}}\n\n    #","ref":"SimpleXml.XmlNode.html#first_child/2-wildcard-ignores-tag-namespace"},{"type":"function","title":"Use Regex to find a child - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  2  \n    ```\n\n    iex> SimpleXml.XmlNode.first_child({\"ns:foo\", [], [{\"xs:bar\", [], [\"1\"]}, {\"xs:bar\", [], [\"2\"]}]}, ~r/.*:BAR/i)\n    {:ok, {\"xs:bar\", [], [\"1\"]}}\n\n    #","ref":"SimpleXml.XmlNode.html#first_child/2-use-regex-to-find-a-child"},{"type":"function","title":"Generates an error when there's no child with the given name - SimpleXml.XmlNode.first_child/2","doc":"Assume that the following XML has been parsed.\n    ```\n        1  \n    ```\n    iex> SimpleXml.XmlNode.first_child({\"foo\", [], [{\"bar\", [], [\"1\"]}]}, \"baz\")\n    {:error, {:child_not_found, \"baz\"}}","ref":"SimpleXml.XmlNode.html#first_child/2-generates-an-error-when-there-s-no-child-with-the-given-name"},{"type":"function","title":"SimpleXml.XmlNode.text/1","doc":"Obtains text within the body of a tag.","ref":"SimpleXml.XmlNode.html#text/1"},{"type":"function","title":"Examples - SimpleXml.XmlNode.text/1","doc":"#","ref":"SimpleXml.XmlNode.html#text/1-examples"},{"type":"function","title":"Obtains the text contents of a tag. - SimpleXml.XmlNode.text/1","doc":"Assume that the following XML has been parsed.\n    ```\n       bar \n    ```\n\n    iex> SimpleXml.XmlNode.text({\"foo\", [], [\"bar\"]})\n    {:ok, \"bar\"}\n\n    #","ref":"SimpleXml.XmlNode.html#text/1-obtains-the-text-contents-of-a-tag"},{"type":"function","title":"Generates an error when the tag contains no text - SimpleXml.XmlNode.text/1","doc":"Assume that the following XML has been parsed.\n    ```\n        1  \n    ```\n    iex> SimpleXml.XmlNode.text({\"foo\", [], [{\"bar\", [], [\"1\"]}]})\n    {:error, {:text_not_found, [{\"bar\", [], [\"1\"]}]}}","ref":"SimpleXml.XmlNode.html#text/1-generates-an-error-when-the-tag-contains-no-text"},{"type":"type","title":"SimpleXml.XmlNode.xml_node/0","doc":"","ref":"SimpleXml.XmlNode.html#t:xml_node/0"}],"content_type":"text/markdown"}